verify

package
v0.23.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AssetSource

type AssetSource func(ctx context.Context, steamID string) (providerID string, sa []steam.Asset, err error)

AssetSource represents inventory asset source provider.

func JoinAssetSource

func JoinAssetSource(providers ...AssetSource) AssetSource

type DeliveryResult

type DeliveryResult struct {
	Status     dotagiftx.DeliveryStatus
	Assets     []steam.Asset
	VerifiedBy string
}

func Delivery

func Delivery(
	ctx context.Context,
	source AssetSource,
	sellerPersona,
	buyerSteamID,
	itemName string,
) (*DeliveryResult, error)

Delivery checks item existence on buyer's inventory.

Returns an error when request has status error or body malformed.

type InventorResult

type InventorResult struct {
	Status     dotagiftx.InventoryStatus
	Assets     []steam.Asset
	VerifiedBy string
}

func Inventory

func Inventory(ctx context.Context, source AssetSource, steamID, itemName string) (*InventorResult, error)

Inventory checks item existence on inventory.

Returns an error when request has status error or response body malformed.

type Source

type Source struct {
	// contains filtered or unexported fields
}

func NewSource

func NewSource(as ...AssetSource) *Source

func (*Source) Delivery

func (s *Source) Delivery(ctx context.Context, sellerPersona, steamID, itemName string) (*DeliveryResult, error)

func (*Source) Inventory

func (s *Source) Inventory(ctx context.Context, steamID, itemName string) (*InventorResult, error)

Directories

Path Synopsis
example
delivery command
inventory command

Jump to