Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultWithPrefix ¶
DefaultWithPrefix returns a default instance of logger with prefix.
Types ¶
type Hook ¶
Hook is a hook that writes logs of specified LogLevels to specified Writer
type Logger ¶
type Logger interface {
// Standard Lib logger methods.
Print(v ...interface{})
Println(v ...interface{})
Printf(format string, v ...interface{})
Panic(v ...interface{})
Panicln(v ...interface{})
Panicf(format string, v ...interface{})
Fatal(v ...interface{})
Fatalln(v ...interface{})
Fatalf(format string, v ...interface{})
// Custom logger methods.
Info(v ...interface{})
Infoln(v ...interface{})
Infof(format string, v ...interface{})
Error(v ...interface{})
Errorln(v ...interface{})
Errorf(format string, v ...interface{})
Debug(v ...interface{})
Debugln(v ...interface{})
Debugf(format string, v ...interface{})
Warn(v ...interface{})
Warnln(v ...interface{})
Warnf(format string, v ...interface{})
}
Logger provides access to logging service.
Click to show internal directories.
Click to hide internal directories.