Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AssetSource ¶
type AssetSource func(ctx context.Context, steamID string) (providerID string, sa []steam.Asset, err error)
AssetSource represents inventory asset source provider.
func JoinAssetSource ¶
func JoinAssetSource(providers ...AssetSource) AssetSource
type DeliveryResult ¶
type DeliveryResult struct {
Status dotagiftx.DeliveryStatus
Assets []steam.Asset
VerifiedBy string
}
func Delivery ¶
func Delivery( ctx context.Context, source AssetSource, sellerPersona, buyerSteamID, itemName string, ) (*DeliveryResult, error)
Delivery checks item existence on buyer's inventory.
Returns an error when request has status error or body malformed.
type InventorResult ¶
type InventorResult struct {
Status dotagiftx.InventoryStatus
Assets []steam.Asset
VerifiedBy string
}
func Inventory ¶
func Inventory(ctx context.Context, source AssetSource, steamID, itemName string) (*InventorResult, error)
Inventory checks item existence on inventory.
Returns an error when request has status error or response body malformed.
Click to show internal directories.
Click to hide internal directories.